@@ -138,18 +138,21 @@ class FileCopier(object):
     def _link_folders(src, dst, linked_folders):
         for linked_folder in linked_folders:
             link = os.readlink(os.path.join(src, linked_folder))
-            # The link is relative to the directory of the "linker_folder"
-            dest_dir = os.path.join(os.path.dirname(linked_folder), link)
-            if os.path.exists(os.path.join(dst, dest_dir)):
-                with tools.chdir(dst):
-                    try:
-                        # Remove the previous symlink
-                        os.remove(linked_folder)
-                    except OSError:
-                        pass
-                    # link is a string relative to linked_folder
-                    # e.j: os.symlink("test/bar", "./foo/test_link") will create a link to foo/test/bar in ./foo/test_link
-                    os.symlink(link, linked_folder)
+            dst_link = os.path.join(dst, linked_folder)
+            try:
+                # Remove the previous symlink
+                os.remove(dst_link)
+            except OSError:
+                pass
+            # link is a string relative to linked_folder
+            # e.j: os.symlink("test/bar", "./foo/test_link") will create a link to foo/test/bar in ./foo/test_link
+            os.symlink(link, dst_link)
+        # Remove empty links
+        for linked_folder in linked_folders:
+            dst_link = os.path.join(dst, linked_folder)
+            abs_path = os.path.realpath(dst_link)
+            if not os.path.exists(abs_path):
+                os.remove(dst_link)
 
     @staticmethod
     def _copy_files(files, src, dst, keep_path, symlinks):
