@@ -1,4 +1,3 @@
-import fnmatch
 import os
 from collections import Counter
 
@@ -14,11 +13,9 @@ from conans.client.installer import ConanInstaller, call_system_requirements
 from conans.client.loader import ConanFileLoader
 from conans.client.manifest_manager import ManifestManager
 from conans.client.output import ScopedOutput, Color
-from conans.client.printer import Printer
 from conans.client.profile_loader import read_conaninfo_profile
 from conans.client.proxy import ConanProxy
-from conans.client.remover import ConanRemover
-from conans.client.graph.require_resolver import RequireResolver
+from conans.client.graph.range_resolver import RangeResolver
 from conans.client.source import config_source_local, complete_recipe_sources
 from conans.client.tools import cross_building, get_cross_building_settings
 from conans.client.userio import UserIO
@@ -29,80 +26,16 @@ from conans.paths import CONANFILE, CONANINFO, CONANFILE_TXT, BUILD_INFO
 from conans.util.files import save, rmdir, normalize, mkdir, load
 from conans.util.log import logger
 from conans.client.loader_parse import load_conanfile_class
-
-
-class BuildMode(object):
-    """ build_mode => ["*"] if user wrote "--build"
-                   => ["hello*", "bye*"] if user wrote "--build hello --build bye"
-                   => False if user wrote "never"
-                   => True if user wrote "missing"
-                   => "outdated" if user wrote "--build outdated"
-    """
-    def __init__(self, params, output):
-        self._out = output
-        self.outdated = False
-        self.missing = False
-        self.never = False
-        self.patterns = []
-        self._unused_patterns = []
-        self.all = False
-        if params is None:
-            return
-
-        assert isinstance(params, list)
-        if len(params) == 0:
-            self.all = True
-        else:
-            for param in params:
-                if param == "outdated":
-                    self.outdated = True
-                elif param == "missing":
-                    self.missing = True
-                elif param == "never":
-                    self.never = True
-                else:
-                    self.patterns.append("%s" % param)
-
-            if self.never and (self.outdated or self.missing or self.patterns):
-                raise ConanException("--build=never not compatible with other options")
-        self._unused_patterns = list(self.patterns)
-
-    def forced(self, conan_file, reference):
-        if self.never:
-            return False
-        if self.all:
-            return True
-
-        if conan_file.build_policy_always:
-            out = ScopedOutput(str(reference), self._out)
-            out.info("Building package from source as defined by build_policy='always'")
-            return True
-
-        ref = reference.name
-        # Patterns to match, if package matches pattern, build is forced
-        force_build = any([fnmatch.fnmatch(ref, pattern) for pattern in self.patterns])
-        return force_build
-
-    def allowed(self, conan_file, reference):
-        return (self.missing or self.outdated or self.forced(conan_file, reference) or
-                conan_file.build_policy_missing)
-
-    def check_matches(self, references):
-        for pattern in list(self._unused_patterns):
-            matched = any(fnmatch.fnmatch(ref, pattern) for ref in references)
-            if matched:
-                self._unused_patterns.remove(pattern)
-
-    def report_matches(self):
-        for pattern in self._unused_patterns:
-            self._out.error("No package matching '%s' pattern" % pattern)
+from conans.client.graph.build_mode import BuildMode
+from conans.client.cmd.download import download_binaries
+from conans.client.graph.printer import print_graph
 
 
 class ConanManager(object):
     """ Manage all the commands logic  The main entry point for all the client
     business logic
     """
-    def __init__(self, client_cache, user_io, runner, remote_manager, search_manager,
+    def __init__(self, client_cache, user_io, runner, remote_manager,
                  settings_preprocessor, recorder, registry):
         assert isinstance(user_io, UserIO)
         assert isinstance(client_cache, ClientCache)
@@ -110,7 +43,6 @@ class ConanManager(object):
         self._user_io = user_io
         self._runner = runner
         self._remote_manager = remote_manager
-        self._search_manager = search_manager
         self._settings_preprocessor = settings_preprocessor
         self._recorder = recorder
         self._registry = registry
@@ -157,10 +89,9 @@ class ConanManager(object):
             self._settings_preprocessor.preprocess(cache_settings)
         return ConanFileLoader(self._runner, cache_settings, profile)
 
-    def get_proxy(self, remote_name=None, manifest_manager=None):
+    def get_proxy(self, remote_name=None):
         remote_proxy = ConanProxy(self._client_cache, self._user_io, self._remote_manager,
-                                  remote_name=remote_name, recorder=self._recorder, registry=self._registry,
-                                  manifest_manager=manifest_manager)
+                                  remote_name=remote_name, recorder=self._recorder, registry=self._registry)
         return remote_proxy
 
     def export_pkg(self, reference, source_folder, build_folder, package_folder, install_folder, profile, force):
@@ -173,16 +104,15 @@ class ConanManager(object):
 
         loader = self.get_loader(profile)
         conanfile = loader.load_virtual([reference], scope_options=True)
-        if install_folder and existing_info_files(install_folder):
-            _load_deps_info(install_folder, conanfile, required=True)
-
         graph_builder = self._get_graph_builder(loader, remote_proxy)
         deps_graph = graph_builder.load_graph(conanfile, check_updates=False, update=False)
 
-        # this is a bit tricky, but works. The loading of a cache package makes the referenced
-        # one, the first of the first level, always existing
-        nodes = deps_graph.direct_requires()
+        # this is a bit tricky, but works. The root (virtual), has only 1 neighbor,
+        # which is the exported pkg
+        nodes = deps_graph.root.neighbors()
         conanfile = nodes[0].conanfile
+        if install_folder and existing_info_files(install_folder):
+            _load_deps_info(install_folder, conanfile, required=True)
         pkg_id = conanfile.info.package_id()
         self._user_io.out.info("Packaging to %s" % pkg_id)
         pkg_reference = PackageReference(reference, pkg_id)
@@ -201,10 +131,11 @@ class ConanManager(object):
         conanfile.develop = True
         package_output = ScopedOutput(str(reference), self._user_io.out)
         if package_folder:
-            packager.export_pkg(conanfile, package_folder, dest_package_folder, package_output)
+            packager.export_pkg(conanfile, pkg_id, package_folder, dest_package_folder,
+                                package_output)
         else:
-            packager.create_package(conanfile, source_folder, build_folder, dest_package_folder,
-                                    install_folder, package_output, local=True)
+            packager.create_package(conanfile, pkg_id, source_folder, build_folder,
+                                    dest_package_folder, install_folder, package_output, local=True)
 
     def download(self, reference, package_ids, remote_name, recipe):
         """ Download conanfile and specified packages to local repository
@@ -214,14 +145,15 @@ class ConanManager(object):
         @param only_recipe: download only the recipe
         """
         assert(isinstance(reference, ConanFileReference))
-        remote_proxy = self.get_proxy(remote_name=remote_name)
-        remote, _ = remote_proxy._get_remote()
+        output = ScopedOutput(str(reference), self._user_io.out)
+        remote = self._registry.remote(remote_name) if remote_name else self._registry.default_remote
         package = self._remote_manager.search_recipes(remote, reference, None)
         if not package:  # Search the reference first, and raise if it doesn't exist
             raise ConanException("'%s' not found in remote" % str(reference))
 
         # First of all download package recipe
-        remote_proxy.get_recipe(reference, check_updates=True, update=True)
+        self._remote_manager.get_recipe(reference, remote)
+        self._registry.set_ref(reference, remote)
 
         if recipe:
             return
@@ -233,16 +165,18 @@ class ConanManager(object):
                                 conanfile, reference)
 
         if package_ids:
-            remote_proxy.download_packages(reference, package_ids)
+            download_binaries(reference, package_ids, self._client_cache, self._remote_manager,
+                              remote, output, self._recorder)
         else:
-            self._user_io.out.info("Getting the complete package list "
-                                   "from '%s'..." % str(reference))
+            output.info("Getting the complete package list "
+                        "from '%s'..." % str(reference))
             packages_props = self._remote_manager.search_packages(remote, reference, None)
             if not packages_props:
                 output = ScopedOutput(str(reference), self._user_io.out)
                 output.warn("No remote binary packages found in remote")
             else:
-                remote_proxy.download_packages(reference, list(packages_props.keys()))
+                download_binaries(reference, list(packages_props.keys()), self._client_cache,
+                                  self._remote_manager, remote, output, self._recorder)
 
     @staticmethod
     def _inject_require(conanfile, inject_require):
@@ -258,8 +192,7 @@ class ConanManager(object):
         conanfile._channel = inject_require.channel
 
     def _get_graph_builder(self, loader, remote_proxy):
-        local_search = self._search_manager
-        resolver = RequireResolver(self._user_io.out, local_search, remote_proxy)
+        resolver = RangeResolver(self._user_io.out, self._client_cache, remote_proxy)
         graph_builder = DepsGraphBuilder(remote_proxy, self._user_io.out, loader, resolver)
         return graph_builder
 
@@ -338,11 +271,7 @@ class ConanManager(object):
             generators = set(generators) if generators else set()
             generators.add("txt")  # Add txt generator by default
 
-        manifest_manager = ManifestManager(manifest_folder, user_io=self._user_io,
-                                           client_cache=self._client_cache,
-                                           verify=manifest_verify,
-                                           interactive=manifest_interactive) if manifest_folder else None
-        remote_proxy = self.get_proxy(remote_name=remote_name, manifest_manager=manifest_manager)
+        remote_proxy = self.get_proxy(remote_name=remote_name)
 
         loader = self.get_loader(profile)
         if not install_reference:
@@ -363,7 +292,7 @@ class ConanManager(object):
         else:
             output = ScopedOutput(str(reference), self._user_io.out)
             output.highlight("Installing package")
-        Printer(self._user_io.out).print_graph(deps_graph, self._registry)
+        print_graph(deps_graph, self._user_io.out)
 
         try:
             if cross_building(loader._settings):
@@ -385,6 +314,20 @@ class ConanManager(object):
         installer.install(deps_graph, profile.build_requires, keep_build, update=update)
         build_mode.report_matches()
 
+        if manifest_folder:
+            manifest_manager = ManifestManager(manifest_folder, user_io=self._user_io,
+                                               client_cache=self._client_cache)
+            for node in deps_graph.nodes:
+                if not node.conan_ref:
+                    continue
+                conanfile = node.conanfile
+                complete_recipe_sources(self._remote_manager, self._client_cache, self._registry,
+                                        conanfile, node.conan_ref)
+            manifest_manager.check_graph(deps_graph,
+                                         verify=manifest_verify,
+                                         interactive=manifest_interactive)
+            manifest_manager.print_log()
+
         if install_folder:
             # Write generators
             if generators is not False:
@@ -407,9 +350,6 @@ class ConanManager(object):
                 if hasattr(deploy_conanfile, "deploy") and callable(deploy_conanfile.deploy):
                     run_deploy(deploy_conanfile, install_folder, output)
 
-        if manifest_manager:
-            manifest_manager.print_log()
-
     def source(self, conanfile_path, source_folder, info_folder):
         """
         :param conanfile_path: Absolute path to a conanfile
@@ -424,9 +364,8 @@ class ConanManager(object):
         conanfile_folder = os.path.dirname(conanfile_path)
         if conanfile_folder != source_folder:
             output.info("Executing exports to: %s" % source_folder)
-            _execute_export(conanfile_path, conanfile, source_folder,
-                            source_folder, output)
-        config_source_local(source_folder, conanfile, output)
+            _execute_export(conanfile_path, conanfile, source_folder, source_folder, output)
+        config_source_local(source_folder, conanfile, conanfile_folder, output)
 
     def imports(self, conan_file_path, dest_folder, info_folder):
         """
@@ -450,7 +389,7 @@ class ConanManager(object):
         output = ScopedOutput("PROJECT", self._user_io.out)
         conanfile = self._load_consumer_conanfile(conanfile_path, install_folder, output,
                                                   deps_info_required=True)
-        packager.create_package(conanfile, source_folder, build_folder, package_folder,
+        packager.create_package(conanfile, None, source_folder, build_folder, package_folder,
                                 install_folder, output, local=True, copy_info=True)
 
     def build(self, conanfile_path, source_folder, build_folder, package_folder, install_folder,
@@ -506,23 +445,6 @@ class ConanManager(object):
             trace = traceback.format_exc().split('\n')
             raise ConanException("Unable to build it successfully\n%s" % '\n'.join(trace[3:]))
 
-    def remove(self, pattern, src=False, build_ids=None, package_ids_filter=None, force=False,
-               remote_name=None, packages_query=None, outdated=False):
-        """ Remove conans and/or packages
-        @param pattern: string to match packages
-        @param src: Remove src folder
-        @param package_ids_filter: list of ids or [] for all list
-        @param build_ids: list of ids or [] for all list
-        @param remote: search on another origin to get packages info
-        @param force: if True, it will be deleted without requesting anything
-        @param packages_query: Only if src is a reference. Query settings and options
-        """
-        remote_proxy = self.get_proxy(remote_name=remote_name)
-        remover = ConanRemover(self._client_cache, self._remote_manager, self._user_io, remote_proxy,
-                               self._registry)
-        remover.remove(pattern, remote_name, src, build_ids, package_ids_filter, force=force,
-                       packages_query=packages_query, outdated=outdated)
-
 
 def _load_deps_info(current_path, conanfile, required):
 
