@@ -6,7 +6,7 @@ from conans.test.utils.tools import TestServer, TestClient
 from conans.model.ref import ConanFileReference
 from conans.util.files import save, load, md5
 from conans.model.ref import PackageReference
-from conans.paths import CONANFILE, SimplePaths
+from conans.paths import CONANFILE, SimplePaths, CONAN_MANIFEST
 from conans.test.utils.test_files import temp_folder
 from conans.model.manifest import FileTreeManifest
 
@@ -66,10 +66,10 @@ class ConsumerFileTest(ConanFile):
                       self.client.user_io.out)
 
         paths = SimplePaths(output_folder)
-        self.assertTrue(os.path.exists(paths.digestfile_conanfile(self.reference)))
+        self.assertTrue(os.path.exists(os.path.join(paths.export(self.reference), CONAN_MANIFEST)))
         package_reference = PackageReference.loads("Hello/0.1@lasote/stable:"
                                                    "5ab84d6acfe1f23c4fae0ab88f26e3a396351ac9")
-        self.assertTrue(os.path.exists(paths.digestfile_package(package_reference)))
+        self.assertTrue(os.path.exists(os.path.join(paths.package(package_reference), CONAN_MANIFEST)))
         # now verify
         self.client.run("create . lasote/stable --verify%s" % dest)
         self.assertIn("Manifest for 'Hello/0.1@lasote/stable': OK", self.client.user_io.out)
@@ -86,10 +86,10 @@ class ConsumerFileTest(ConanFile):
         real_folder = folder or ".conan_manifests"
         output_folder = os.path.join(self.client.current_folder, real_folder)
         paths = SimplePaths(output_folder)
-        self.assertTrue(os.path.exists(paths.digestfile_conanfile(self.reference)))
+        self.assertTrue(os.path.exists(os.path.join(paths.export(self.reference), CONAN_MANIFEST)))
         package_reference = PackageReference.loads("Hello/0.1@lasote/stable:"
                                                    "5ab84d6acfe1f23c4fae0ab88f26e3a396351ac9")
-        self.assertTrue(os.path.exists(paths.digestfile_package(package_reference)))
+        self.assertTrue(os.path.exists(os.path.join(paths.package(package_reference), CONAN_MANIFEST)))
 
         # again should do nothing
         self.client.run("install %s --build missing --manifests %s"
@@ -145,18 +145,15 @@ class ConanFileTest(ConanFile):
 
         output_folder = os.path.join(self.client.current_folder, folder)
         paths = SimplePaths(output_folder)
-        self.assertTrue(os.path.exists(paths.digestfile_conanfile(self.reference)))
-        self.assertTrue(os.path.exists(paths.digestfile_package(package_reference)))
-        package_reference = PackageReference.loads("Hello2/0.1@lasote/stable:"
-                                                   "5ab84d6acfe1f23c4fae0ab88f26e3a396351ac9")
-        self.assertTrue(os.path.exists(paths.digestfile_package(package_reference)))
+        self.assertTrue(os.path.exists(os.path.join(paths.export(self.reference), CONAN_MANIFEST)))
+        self.assertTrue(os.path.exists(os.path.join(paths.package(package_reference), CONAN_MANIFEST)))
 
     def remote_capture_verify_manifest_test(self):
         self.client.run("upload %s --all" % str(self.reference))
         self.client.run("remove Hello* -f")
         files = {"conanfile.txt": "[requires]\nHello/0.1@lasote/stable"}
         self.client.save(files, clean_first=True)
-        self._capture_verify_manifest(".", remote="default:")
+        self._capture_verify_manifest(".", remote="default")
 
     def _failed_verify(self, reference, remote="local cache"):
         self.client.run("install %s --build missing --manifests" % str(reference))
@@ -168,11 +165,11 @@ class ConanFileTest(ConanFile):
 
         output_folder = os.path.join(self.client.current_folder, ".conan_manifests")
         paths = SimplePaths(output_folder)
-        self.assertTrue(os.path.exists(paths.digestfile_conanfile(self.reference)))
+        self.assertTrue(os.path.exists(os.path.join(paths.export(self.reference), CONAN_MANIFEST)))
 
         package_reference = PackageReference.loads("Hello/0.1@lasote/stable:"
                                                    "5ab84d6acfe1f23c4fae0ab88f26e3a396351ac9")
-        self.assertTrue(os.path.exists(paths.digestfile_package(package_reference)))
+        self.assertTrue(os.path.exists(os.path.join(paths.package(package_reference), CONAN_MANIFEST)))
 
         client = TestClient(servers=self.servers, users={"default": [("lasote", "mypass")]})
         conanfile = """from conans import ConanFile
@@ -215,11 +212,11 @@ class ConanFileTest(ConanFile):
 
         output_folder = os.path.join(self.client.current_folder, ".conan_manifests")
         paths = SimplePaths(output_folder)
-        self.assertTrue(os.path.exists(paths.digestfile_conanfile(self.reference)))
+        self.assertTrue(os.path.exists(os.path.join(paths.export(self.reference), CONAN_MANIFEST)))
 
         package_reference = PackageReference.loads("Hello/0.1@lasote/stable:"
                                                    "5ab84d6acfe1f23c4fae0ab88f26e3a396351ac9")
-        self.assertTrue(os.path.exists(paths.digestfile_package(package_reference)))
+        self.assertTrue(os.path.exists(os.path.join(paths.package(package_reference), CONAN_MANIFEST)))
 
         client = TestClient(servers=self.servers, users={"default": [("lasote", "mypass")]})
 
@@ -286,7 +283,7 @@ class ConanFileTest(ConanFile):
                                                    "5ab84d6acfe1f23c4fae0ab88f26e3a396351ac9")
         package_path = self.client.paths.package(package_reference)
         file_path = os.path.join(package_path, "conaninfo.txt")
-        save(file_path, load(file_path) + "RANDOM STRING")
+        save(file_path, load(file_path) + "  ")
 
         self.client.run("install %s --build missing --manifests" % str(self.reference),
                         ignore_error=True)
